# dragons96_tools dragons96 个人Python工具包 (Python >= 3.9)

## 仓库地址: https://gitee.com/dragons96/py_dragons96_tools

## 联系方式, qq: 521274311 邮箱: 521274311@qq.com

## 安装
```shell
pip install dragons96_tools --upgrade
```


## APIs
### [一. `dragons96_tools.logger` 日志工具包(通过setup方法设置日志文件+loguru框架记录日志)](./docs/日志工具包.md)
### [二. `dragons96_tools.builders` 特定格式内容建造器, 例如: html标签, markdown语法等](./docs/Html、Markdown建造器.md)
### [三. `dragons96_tools.files` 文件/文件类型数据处理工具, 例如: json, csv, yaml, ini等](./docs/文件或文件类型数据处理工具.md)
### [四. `dragons96_tools.models` pydantic Model 封装等, 墙裂推荐, 业务上均应该使用pydantic](./docs/pydantic封装.md)
### [五. `dragons96_tools.notices` 通知工具, 例如: 飞书通知、邮箱通知等](./docs/通知工具.md)
### [六. `dragons96_tools.cryptography` 常用加密解密包, 例如: md5, base64, hmac等](./docs/常用加密解密工具.md)
### [七、`dragons96_tools.env` 多环境管理工具包, 例如: 开发环境、测试环境、正式环境等](./docs/多环境工具包.md)
### [八、`dragons96_tools.sqlalchemy` sqlalchemy ORM工具包](./docs/sqlalchemy工具包.md)
### [九、`dragons96_tools.mysql.pymysql` pymysql 工具包](./docs/pymysql工具包.md)
### [十、`dragons96_tools.impala.impyla` impyla 工具包](./docs/impyla工具包.md)
### [十一、`dragons96_tools.clickhouse.clickhouse_driver` clickhouse_driver 工具包](./docs/clickhouse_driver工具包.md)
### [十二、`dragons96_tools.retry` 重试工具](./docs/重试工具.md)
### [十三、`dragons96_tools.task` 任务工具](./docs/任务工具.md)
### [十四、`dragons96_tools.cache` 缓存工具](./docs/缓存工具.md)]
